==> geant4.9.6.p03.tar.gz: geant4.9.6.p03/examples/.doxygen/Doxymodules_analysis.h <==
// $Id: Doxymodules_analysis.h 60059 2012-06-27 13:00:49Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_analysis.h
/// \brief The page that defines the extended/analysis examples modules


/** @defgroup extended_analysis analysis
 *  Extended examples analysis classes
 *  @{
 */

/** @defgroup extended_analysis_A01 A01
 *  Analysis example A01 
 *  @ingroup extended_analysis
 *  @{
 */

  class A01AnalysisManager {};
  class A01CellParameterisation {};
  class A01DetectorConstMessenger {};
  class A01DetectorConstruction {};
  class A01DriftChamber {};
  class A01DriftChamberHit {};
  class A01EmCalorimeter {};
  class A01EmCalorimeterHit {};
  class A01EMPhysics {};
  class A01EventAction {};
  class A01EventActionMessenger {};
  class A01GeneralPhysics {};
  class A01HadCalorimeter {};
  class A01HadCalorimeterHit {};
  class A01HadronPhysics {};
  class A01Hodoscope {};
  class A01HodoscopeHit {};
  class A01IonPhysics {};
  class A01MagneticField {};
  class A01MagneticFieldMessenger {};
  class A01MuonPhysics {};
  class A01PhysicsList {};
  class A01PrimaryGeneratorAction {};
  class A01PrimaryGeneratorMessenger {};

/** @} */

/** @defgroup extended_analysis_shared shared
 *  The shared analysis classes have their
 *  <a href="../html_analysis_shared/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_AnaEx01 AnaEx01
 *  Analysis AnaEx01 example has its 
 *  <a href="../html_AnaEx01/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_AnaEx02 AnaEx02
 *  Analysis AnaEx02 example has its 
 *  <a href="../html_AnaEx02/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_AnaEx03 AnaEx03
 *  Analysis AnaEx03 example has its 
 *  <a href="../html_AnaEx03/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_N03Con N03Con
 *  Analysis AnaEx03 example has its 
 *  <a href="../html_N03Con/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */
/** @} */


/** @} */

==> geant4.10.00.p03.tar.gz: geant4.10.00.p03/examples/.doxygen/Doxymodules_analysis.h <==
// $Id: Doxymodules_analysis.h 78005 2013-12-02 08:29:57Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_analysis.h
/// \brief The page that defines the extended/analysis examples modules


/** @defgroup extended_analysis analysis
 *  Extended examples analysis classes
 *  @{
 */

/** @defgroup extended_analysis_A01 A01
 *  Analysis example A01 
 *  @ingroup extended_analysis
 *  @{
 */

  class A01AnalysisManager {};
  class A01CellParameterisation {};
  class A01DetectorConstMessenger {};
  class A01DetectorConstruction {};
  class A01DriftChamber {};
  class A01DriftChamberHit {};
  class A01EmCalorimeter {};
  class A01EmCalorimeterHit {};
  class A01EMPhysics {};
  class A01EventAction {};
  class A01EventActionMessenger {};
  class A01GeneralPhysics {};
  class A01HadCalorimeter {};
  class A01HadCalorimeterHit {};
  class A01HadronPhysics {};
  class A01Hodoscope {};
  class A01HodoscopeHit {};
  class A01IonPhysics {};
  class A01MagneticField {};
  class A01MagneticFieldMessenger {};
  class A01MuonPhysics {};
  class A01PhysicsList {};
  class A01PrimaryGeneratorAction {};
  class A01PrimaryGeneratorMessenger {};

/** @} */

/** @defgroup extended_analysis_shared shared
 *  The shared analysis classes have their
 *  <a href="../html_analysis_shared/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_AnaEx01 AnaEx01
 *  Analysis AnaEx01 example has its 
 *  <a href="../html_AnaEx01/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_AnaEx02 AnaEx02
 *  Analysis AnaEx02 example has its 
 *  <a href="../html_AnaEx02/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_AnaEx03 AnaEx03
 *  Analysis AnaEx03 example has its 
 *  <a href="../html_AnaEx03/html/index.html">standalone documentation </a>
 *  @ingroup extended_analysis
 *  @{
 */

/** @} */

/** @defgroup extended_analysis_B1Con B1Con
 *  Analysis example B1Con 
 *  @ingroup extended_analysis
 *  @{
 */

  class B1ConActionInitialization{};
  class B1ConRunAction{};
  class B1ConRun{};
  class B1DetectorConstruction{};
  class B1EventAction{};
  class B1PrimaryGeneratorAction{};
  class B1Run{};
  class B1SteppingAction{};

/** @} */


/** @} */
